==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/items/menu/PluginMenuItem.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.menu;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.Shell;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.items.ItemContainer;
import org.herac.tuxguitar.gui.plugins.TGPlugin;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class PluginMenuItem implements ItemContainer{
	private boolean shouldShow;
    private MenuItem pluginMenuItem;
    private Menu menu; 
    
    public PluginMenuItem(Shell shell,Menu parent, int style) {
    	this.shouldShow = !TuxGuitar.instance().getPluginManager().getPluginItems().isEmpty();
    	if(shouldShow){
    		this.pluginMenuItem = new MenuItem(parent, style);
    		this.menu = new Menu(shell, SWT.DROP_DOWN);
    	}
    }    
    
    
    public void showItems(){  
    	if(shouldShow){
    		for(int i = 0; i < TuxGuitar.instance().getPluginManager().getPluginItems().size();i ++){
    			final TGPlugin plugin = (TGPlugin)TuxGuitar.instance().getPluginManager().getPluginItems().get(i);
    			
    			MenuItem item = plugin.getItem().getMenuItem(this.menu);
    		}
    		this.pluginMenuItem.setMenu(menu);
        
    		this.loadProperties();
    	}
    }    
    
    public void update(){        
    }
    
    public void loadProperties(){
    	if(this.pluginMenuItem != null){
    		this.pluginMenuItem.setText(TuxGuitar.getProperty("plugins"));
    	}
    }         
}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/items/menu/PluginMenuItem.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.menu;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.Shell;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.items.MenuItems;
import org.herac.tuxguitar.gui.system.plugins.TGPlugin;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class PluginMenuItem implements MenuItems{
	private boolean shouldShow;
    private MenuItem pluginMenuItem;
    private Menu menu; 
    
    public PluginMenuItem(Shell shell,Menu parent, int style) {
    	this.shouldShow = !TuxGuitar.instance().getPluginManager().getPluginItems().isEmpty();
    	if(shouldShow){
    		this.pluginMenuItem = new MenuItem(parent, style);
    		this.menu = new Menu(shell, SWT.DROP_DOWN);
    	}
    }    
    
    
    public void showItems(){  
    	if(shouldShow){
    		for(int i = 0; i < TuxGuitar.instance().getPluginManager().getPluginItems().size();i ++){
    			final TGPlugin plugin = (TGPlugin)TuxGuitar.instance().getPluginManager().getPluginItems().get(i);
    			
    			MenuItem item = plugin.getItem().getMenuItem(this.menu);
    		}
    		this.pluginMenuItem.setMenu(menu);
        
    		this.loadProperties();
    	}
    }    
    
    public void update(){        
    }
    
    public void loadProperties(){
    	if(this.pluginMenuItem != null){
    		this.pluginMenuItem.setText(TuxGuitar.getProperty("plugins"));
    	}
    }         
}
